<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msa="http://www.publictalksoftware.co.uk/msa">
  <xsl:output method="html" indent="yes" version="4.01"
    doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
    doctype-public="//W3C//DTD XHTML 1.0 Transitional//EN"/>
  <xsl:template match="/">
    <html>
      <head>
        <title>Report studenti</title>
        <link rel="stylesheet" type="text/css" href="Custom Report Studenti.css"/>
		<h2 style="text-align:center">Report ultime assegnazioni studenti</h2>
	 </head>
      <body>
        <xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.XML')"/>
        <xsl:variable name="Labels" select="document('LabelsInfo.XML')"/>
        <table>
          <thead>
            <th class="cellSortHeading" id="column-1">Studenti</th>
            <th class="cellSortHeading" id="column-2">Ultima data Studente</th>
            <th class="cellSortHeading" id="column-3">Ultima data Lettura</th>
            <th class="cellSortHeading" id="column-4">Ultima data Proclamatore</th>
            <th class="cellSortHeading" id="column-5">Ultima data Discorso</th>
            <th class="cellSortHeading" id="column-6">Ultima data Assistente</th>
          </thead>
          <tbody>
            <xsl:apply-templates select="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher[msa:Assignments/@Student='true' or msa:Assignments/@Assistant='true']">
              <xsl:sort select="msa:Name" data-type="text" order="ascending"/>
              <xsl:with-param name="strAssistant" select="$Labels/Labels/Assistant"/>
              <xsl:with-param name="strBibleReading" select="$Labels/Labels/BibleReading"/>
              <xsl:with-param name="strTalk" select="$Labels/Labels/Talk"/>
              <xsl:with-param name="NowDay" select="/MeetingWorkBook/Settings/Now/@Day"/>
              <xsl:with-param name="NowMonth" select="/MeetingWorkBook/Settings/Now/@Month"/>
              <xsl:with-param name="NowYear" select="/MeetingWorkBook/Settings/Now/@Year"/>
            </xsl:apply-templates>
          </tbody>
        </table>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="msa:Publisher">
    <xsl:param name="strAssistant"/>
    <xsl:param name="strBibleReading"/>
    <xsl:param name="strTalk"/>
    <xsl:param name="NowDay"/>
    <xsl:param name="NowMonth"/>
    <xsl:param name="NowYear"/>
    <xsl:variable name="HistoryDB" select="document('AssignHistory.XML')"/>
    <xsl:variable name ="SearchName" select="msa:Name"/>
    <tr>
      <!--The first cell is the name-->
      <td>
        <xsl:value-of select="msa:Name"/>
      </td>
      <!--The next cell is the most recent Student date-->
      <!--We sort the entries in date descending order so that the first entry is the most recent-->
      <td class="cellDate">
        <xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Type != $strAssistant and Name = $SearchName]">
          <xsl:sort select="$HistoryDB/AssignmentHistory/*" order="descending" data-type="text"/>
          <!--We only want the first entry-->
          <xsl:if test="position()=1">
            <xsl:call-template name="DisplayItemDate">
              <xsl:with-param name="ItemDate" select="name(../..)"/>
              <xsl:with-param name="NowDay" select="$NowDay"/>
              <xsl:with-param name="NowMonth" select="$NowMonth"/>
              <xsl:with-param name="NowYear" select="$NowYear"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>
        <!--If no entries were found then it need to write out "<xsl:text> </xsl:text>" How?-->
      </td>
      <!--The next cell is the most recent Bible Reading date-->
      <!--We sort the entries in date descending order so that the first entry is the most recent-->
      <td class="cellDate">
        <xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description = $strBibleReading and Name = $SearchName]">
          <xsl:sort select="$HistoryDB/AssignmentHistory/*" order="descending" data-type="text"/>
          <!--We only want the first entry-->
          <xsl:if test="position()=1">
            <xsl:call-template name="DisplayItemDate">
              <xsl:with-param name="ItemDate" select="name(../..)"/>
              <xsl:with-param name="NowDay" select="$NowDay"/>
              <xsl:with-param name="NowMonth" select="$NowMonth"/>
              <xsl:with-param name="NowYear" select="$NowYear"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>
        <!--If no entries were found then it need to write out "<xsl:text> </xsl:text>" How?-->
      </td>
      <!--The next cell is the most recent Publisher date-->
      <!--We sort the entries in date descending order so that the first entry is the most recent-->
      <td class="cellDate">
        <xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description != $strTalk and Description != $strBibleReading and Type != $strAssistant and Name = $SearchName]">
          <xsl:sort select="$HistoryDB/AssignmentHistory/*" order="descending" data-type="text"/>
          <!--We only want the first entry-->
          <xsl:if test="position()=1">
            <xsl:call-template name="DisplayItemDate">
              <xsl:with-param name="ItemDate" select="name(../..)"/>
              <xsl:with-param name="NowDay" select="$NowDay"/>
              <xsl:with-param name="NowMonth" select="$NowMonth"/>
              <xsl:with-param name="NowYear" select="$NowYear"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>
        <!--If no entries were found then it need to write out "<xsl:text> </xsl:text>" How?-->
      </td>
      <!--The next cell is the most recent Talk date-->
      <!--We sort the entries in date descending order so that the first entry is the most recent-->
      <td class="cellDate">
        <xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description = $strTalk and Name = $SearchName]">
          <xsl:sort select="$HistoryDB/AssignmentHistory/*" order="descending" data-type="text"/>
          <!--We only want the first entry-->
          <xsl:if test="position()=1">
            <xsl:call-template name="DisplayItemDate">
              <xsl:with-param name="ItemDate" select="name(../..)"/>
              <xsl:with-param name="NowDay" select="$NowDay"/>
              <xsl:with-param name="NowMonth" select="$NowMonth"/>
              <xsl:with-param name="NowYear" select="$NowYear"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>
        <!--If no entries were found then it need to write out "<xsl:text> </xsl:text>" How?-->
      </td>
      <!--The last cell is the most recent Assistant date-->
      <!--We sort the entries in date descending order so that the first entry is the most recent-->
      <td class="cellDate">
        <xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Type = $strAssistant and Name = $SearchName]">
          <xsl:sort select="$HistoryDB/AssignmentHistory/*" order="descending" data-type="text"/>
          <!--We only want the first entry-->
          <xsl:if test="position()=1">
            <xsl:call-template name="DisplayItemDate">
              <xsl:with-param name="ItemDate" select="name(../..)"/>
              <xsl:with-param name="NowDay" select="$NowDay"/>
              <xsl:with-param name="NowMonth" select="$NowMonth"/>
              <xsl:with-param name="NowYear" select="$NowYear"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>
        <!--If no entries were found then it need to write out "<xsl:text> </xsl:text>" How?-->
      </td>
    </tr>
  </xsl:template>

  <xsl:template name="DisplayItemDate">
    <xsl:param name="ItemDate"/>
    <xsl:param name="NowDay" select="//MeetingWorkBook/Settings/Now/@Day"/>
    <xsl:param name="NowMonth" select="//MeetingWorkBook/Settings/Now/@Month"/>
    <xsl:param name="NowYear" select="//MeetingWorkBook/Settings/Now/@Year"/>

    <xsl:variable name="Day" select="substring($ItemDate, 8, 2)"/>
    <xsl:variable name="Month" select="substring($ItemDate, 6, 2)"/>
    <xsl:variable name="Year" select="substring($ItemDate, 2, 4)"/>

    <xsl:choose>
      <xsl:when test="($Day &gt; $NowDay and $Month &gt;= $NowMonth and $Year &gt;= $NowYear) or ($Month &gt; $NowMonth and $Year &gt;= $NowYear) or ($Year &gt; $NowYear)">
        <span class="FutureDate">
          <xsl:value-of select="$Day"/>
          <xsl:text>/</xsl:text>
          <xsl:value-of select="$Month"/>
          <xsl:text>/</xsl:text>
          <xsl:value-of select="$Year"/>
        </span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$Day"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="$Month"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="$Year"/>
      </xsl:otherwise>
    </xsl:choose>
    <!--<xsl:value-of select="substring($ItemDate, 8, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($ItemDate, 6, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($ItemDate, 2, 4)"/>-->
  </xsl:template>
  
</xsl:stylesheet>

